MockJwtService

Struct MockJwtService 

pub struct MockJwtService<C>{ /* private fields */ }

Implementations

Source

impl<C> MockJwtService<C>

pub fn checkpoint(&mut self)

Validate that all current expectations for all methods have been satisfied, and discard them.

pub fn new() -> Self

Create a new mock object with no expectations.

This method will not be generated if the real struct already has a new method. However, it will be generated if the struct implements a trait with a new method. The trait’s new method can still be called like <MockX as TraitY>::new

Source

impl<C> MockJwtService<C>

pub fn expect_encode(&mut self) -> &mut Expectation<C>

Create an Expectation for mocking the encode method

pub fn expect_decode(&mut self) -> &mut Expectation<C>

Create an Expectation for mocking the decode method