pub struct MockJwtService<C>where
C: Serialize + DeserializeOwned,{ /* private fields */ }Implementations
Sourceimpl<C> MockJwtService<C>where
C: Serialize + DeserializeOwned,
impl<C> MockJwtService<C>where
C: Serialize + DeserializeOwned,
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl<C> MockJwtService<C>where
C: Serialize + DeserializeOwned,
impl<C> MockJwtService<C>where
C: Serialize + DeserializeOwned,
Sourcepub fn expect_encode(&mut self) -> &mut Expectation<C>
pub fn expect_encode(&mut self) -> &mut Expectation<C>
Create an Expectation for mocking the encode method
Sourcepub fn expect_decode(&mut self) -> &mut Expectation<C>
pub fn expect_decode(&mut self) -> &mut Expectation<C>
Create an Expectation for mocking the decode method